@@ -15,8 +15,9 @@
 
 #include <CalendarSupport/Utils>
 
-#include <Akonadi/Calendar/ETMCalendar>
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/CalendarUtils>
+#include <Akonadi/ETMCalendar>
+#include <Akonadi/IncidenceChanger>
 
 #include <KCalUtils/IncidenceFormatter>
 #include <KCalendarCore/Visitor>
@@ -92,16 +93,12 @@ bool ListViewItem::operator<(const QTreeWidgetItem &other) const
     }
 }
 
-class Q_DECL_HIDDEN ListView::Private
+class EventViews::ListViewPrivate
 {
 public:
-    Private()
-    {
-    }
+    ListViewPrivate() = default;
 
-    ~Private()
-    {
-    }
+    ~ListViewPrivate() = default;
 
     void addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidenceList, QDate date);
     void addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &, QDate date);
@@ -127,7 +124,7 @@ public:
   This class provides the initialization of a ListViewItem for calendar
   components using the Incidence::Visitor.
 */
-class ListView::Private::ListItemVisitor : public KCalendarCore::Visitor
+class ListViewPrivate::ListItemVisitor : public KCalendarCore::Visitor
 {
 public:
     ListItemVisitor(ListViewItem *item, QDate dt)
@@ -136,9 +133,7 @@ public:
     {
     }
 
-    ~ListItemVisitor() override
-    {
-    }
+    ~ListItemVisitor() override = default;
 
     bool visit(const Event::Ptr &) override;
     bool visit(const Todo::Ptr &) override;
@@ -154,7 +149,7 @@ private:
     QDate mStartDate;
 };
 
-bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
+bool ListViewPrivate::ListItemVisitor::visit(const Event::Ptr &e)
 {
     QIcon eventPxmp;
     if (e->customProperty("KABC", "ANNIVERSARY") == QLatin1String("YES")) {
@@ -196,7 +191,7 @@ bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
     return true;
 }
 
-bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
+bool ListViewPrivate::ListItemVisitor::visit(const Todo::Ptr &t)
 {
     mItem->setIcon(Summary_Column, QIcon::fromTheme(t->iconName()));
 
@@ -245,7 +240,7 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
     return true;
 }
 
-bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
+bool ListViewPrivate::ListItemVisitor::visit(const Journal::Ptr &j)
 {
     mItem->setIcon(Summary_Column, QIcon::fromTheme(j->iconName()));
 
@@ -271,7 +266,7 @@ bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
 
 ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, bool nonInteractive)
     : EventView(parent)
-    , d(new Private())
+    , d(new ListViewPrivate())
 {
     setCalendar(calendar);
     d->mActiveItem = nullptr;
@@ -295,23 +290,19 @@ ListView::ListView(const Akonadi::ETMCalendar::Ptr &calendar, QWidget *parent, b
     layoutTop->addWidget(d->mTreeWidget);
 
     QObject::connect(d->mTreeWidget,
-                     QOverload<const QModelIndex &>::of(&QTreeWidget::doubleClicked),
+                     qOverload<const QModelIndex &>(&QTreeWidget::doubleClicked),
                      this,
-                     QOverload<const QModelIndex &>::of(&ListView::defaultItemAction));
+                     qOverload<const QModelIndex &>(&ListView::defaultItemAction));
     QObject::connect(d->mTreeWidget, &QTreeWidget::customContextMenuRequested, this, &ListView::popupMenu);
     QObject::connect(d->mTreeWidget, &QTreeWidget::itemSelectionChanged, this, &ListView::processSelectionChange);
-    QObject::connect(d->mTreeWidget->header(), &QHeaderView::sortIndicatorChanged,
-                     this, &ListView::slotSortIndicatorChanged);
+    QObject::connect(d->mTreeWidget->header(), &QHeaderView::sortIndicatorChanged, this, &ListView::slotSortIndicatorChanged);
 
     d->mSelectedDates.append(QDate::currentDate());
 
     updateView();
 }
 
-ListView::~ListView()
-{
-    delete d;
-}
+ListView::~ListView() = default;
 
 int ListView::currentDateCount() const
 {
@@ -379,14 +370,14 @@ void ListView::showAll()
     d->addIncidences(calendar(), calendar()->incidences(), QDate());
 }
 
-void ListView::Private::addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidences, QDate date)
+void ListViewPrivate::addIncidences(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::List &incidences, QDate date)
 {
     for (const KCalendarCore::Incidence::Ptr &incidence : incidences) {
         addIncidence(calendar, incidence, date);
     }
 }
 
-void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &item, QDate date)
+void ListViewPrivate::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const Akonadi::Item &item, QDate date)
 {
     Q_ASSERT(calendar);
     if (item.isValid() && item.hasPayload<KCalendarCore::Incidence::Ptr>()) {
@@ -394,7 +385,7 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
     }
 }
 
-void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &incidence, QDate date)
+void ListViewPrivate::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar, const KCalendarCore::Incidence::Ptr &incidence, QDate date)
 {
     if (!incidence) {
         return;
@@ -423,7 +414,7 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
 
     // set tooltips
     for (int col = 0; col < Dummy_EOF_Column; ++col) {
-        item->setToolTip(col, IncidenceFormatter::toolTipStr(CalendarSupport::displayName(calendar.data(), aitem.parentCollection()), incidence));
+        item->setToolTip(col, IncidenceFormatter::toolTipStr(Akonadi::CalendarUtils::displayName(calendar.data(), aitem.parentCollection()), incidence));
     }
 
     ListItemVisitor v(item, mStartDate);
@@ -447,14 +438,14 @@ void ListView::showIncidences(const Akonadi::Item::List &itemList, const QDate &
 
 void ListView::changeIncidenceDisplay(const Akonadi::Item &aitem, int action)
 {
-    const Incidence::Ptr incidence = CalendarSupport::incidence(aitem);
+    const Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(aitem);
     ListViewItem *item = nullptr;
     const QDate f = d->mSelectedDates.constFirst();
     const QDate l = d->mSelectedDates.constLast();
 
     QDate date;
     if (CalendarSupport::hasTodo(aitem)) {
-        date = CalendarSupport::todo(aitem)->dtDue().toLocalTime().date();
+        date = Akonadi::CalendarUtils::todo(aitem)->dtDue().toLocalTime().date();
     } else {
         date = incidence->dtStart().toLocalTime().date();
     }
@@ -485,7 +476,7 @@ void ListView::changeIncidenceDisplay(const Akonadi::Item &aitem, int action)
     }
 }
 
-ListViewItem *ListView::Private::getItemForIncidence(const Akonadi::Item &aitem)
+ListViewItem *ListViewPrivate::getItemForIncidence(const Akonadi::Item &aitem)
 {
     int index = 0;
     while (QTreeWidgetItem *it = mTreeWidget->topLevelItem(index)) {
@@ -531,7 +522,7 @@ void ListView::popupMenu(const QPoint &point)
         // FIXME: For recurring incidences we don't know the date of this
         // occurrence, there's no reference to it at all!
 
-        Q_EMIT showIncidencePopupSignal(aitem, CalendarSupport::incidence(aitem)->dtStart().date());
+        Q_EMIT showIncidencePopupSignal(aitem, Akonadi::CalendarUtils::incidence(aitem)->dtStart().date());
     } else {
         Q_EMIT showNewEventPopupSignal();
     }
